// ------------------------------------------------------------------------------
//  <autogenerated>
//      This code was generated by a tool.
//      Mono Runtime Version: 2.0.50727.42
// 
//      Changes to this file may cause incorrect behavior and will be lost if 
//      the code is regenerated.
//  </autogenerated>
// ------------------------------------------------------------------------------

namespace YahtzeeSharp {
    
    
    public partial class dlgFinished {
        
        private Gtk.VBox vbox2;
        
        private Gtk.Label label1;
        
        private Gtk.HBox hbox1;
        
        private Gtk.Image image1;
        
        private Gtk.VBox vbox3;
        
        private Gtk.Label lblPlayerName;
        
        private Gtk.Label label2;
        
        private Gtk.Label lblScore;
        
        private Gtk.Label label4;
        
        private Gtk.HSeparator hseparator1;
        
        private Gtk.Button cmdNo;
        
        private Gtk.Button cmdYes;
        
        protected virtual void Build() {
            Stetic.Gui.Initialize(this);
            // Widget YahtzeeSharp.dlgFinished
            this.WidthRequest = 405;
            this.Name = "YahtzeeSharp.dlgFinished";
            this.Title = Mono.Unix.Catalog.GetString("Congratulations");
            this.Icon = Gdk.Pixbuf.LoadFromResource("YSlogo.png");
            this.WindowPosition = ((Gtk.WindowPosition)(4));
            this.Modal = true;
            this.BorderWidth = ((uint)(3));
            this.Resizable = false;
            this.AllowGrow = false;
            this.DestroyWithParent = true;
            this.SkipPagerHint = true;
            this.SkipTaskbarHint = true;
            this.HasSeparator = false;
            // Internal child YahtzeeSharp.dlgFinished.VBox
            Gtk.VBox w1 = this.VBox;
            w1.Name = "dialog1_VBox";
            w1.BorderWidth = ((uint)(2));
            // Container child dialog1_VBox.Gtk.Box+BoxChild
            this.vbox2 = new Gtk.VBox();
            this.vbox2.Name = "vbox2";
            this.vbox2.Spacing = 6;
            // Container child vbox2.Gtk.Box+BoxChild
            this.label1 = new Gtk.Label();
            this.label1.Name = "label1";
            this.label1.LabelProp = Mono.Unix.Catalog.GetString("<span size=\"xx-large\"><b>Congratulations</b></span>");
            this.label1.UseMarkup = true;
            this.vbox2.Add(this.label1);
            Gtk.Box.BoxChild w2 = ((Gtk.Box.BoxChild)(this.vbox2[this.label1]));
            w2.Position = 0;
            w2.Expand = false;
            w2.Fill = false;
            // Container child vbox2.Gtk.Box+BoxChild
            this.hbox1 = new Gtk.HBox();
            this.hbox1.Name = "hbox1";
            this.hbox1.Homogeneous = true;
            this.hbox1.Spacing = 6;
            // Container child hbox1.Gtk.Box+BoxChild
            this.image1 = new Gtk.Image();
            this.image1.Name = "image1";
            this.image1.Pixbuf = Gdk.Pixbuf.LoadFromResource("taz.gif");
            this.hbox1.Add(this.image1);
            Gtk.Box.BoxChild w3 = ((Gtk.Box.BoxChild)(this.hbox1[this.image1]));
            w3.Position = 0;
            w3.Expand = false;
            w3.Fill = false;
            // Container child hbox1.Gtk.Box+BoxChild
            this.vbox3 = new Gtk.VBox();
            this.vbox3.Name = "vbox3";
            this.vbox3.Spacing = 8;
            // Container child vbox3.Gtk.Box+BoxChild
            this.lblPlayerName = new Gtk.Label();
            this.lblPlayerName.Name = "lblPlayerName";
            this.lblPlayerName.LabelProp = Mono.Unix.Catalog.GetString("<b>New Player</b>");
            this.lblPlayerName.UseMarkup = true;
            this.vbox3.Add(this.lblPlayerName);
            Gtk.Box.BoxChild w4 = ((Gtk.Box.BoxChild)(this.vbox3[this.lblPlayerName]));
            w4.Position = 0;
            w4.Expand = false;
            w4.Fill = false;
            // Container child vbox3.Gtk.Box+BoxChild
            this.label2 = new Gtk.Label();
            this.label2.Name = "label2";
            this.label2.LabelProp = Mono.Unix.Catalog.GetString("Your Score Was:");
            this.vbox3.Add(this.label2);
            Gtk.Box.BoxChild w5 = ((Gtk.Box.BoxChild)(this.vbox3[this.label2]));
            w5.Position = 1;
            w5.Expand = false;
            w5.Fill = false;
            // Container child vbox3.Gtk.Box+BoxChild
            this.lblScore = new Gtk.Label();
            this.lblScore.Name = "lblScore";
            this.lblScore.LabelProp = Mono.Unix.Catalog.GetString("0");
            this.vbox3.Add(this.lblScore);
            Gtk.Box.BoxChild w6 = ((Gtk.Box.BoxChild)(this.vbox3[this.lblScore]));
            w6.Position = 2;
            w6.Expand = false;
            w6.Fill = false;
            this.hbox1.Add(this.vbox3);
            Gtk.Box.BoxChild w7 = ((Gtk.Box.BoxChild)(this.hbox1[this.vbox3]));
            w7.Position = 1;
            w7.Expand = false;
            w7.Fill = false;
            w7.Padding = ((uint)(6));
            this.vbox2.Add(this.hbox1);
            Gtk.Box.BoxChild w8 = ((Gtk.Box.BoxChild)(this.vbox2[this.hbox1]));
            w8.Position = 1;
            w8.Expand = false;
            w8.Fill = false;
            // Container child vbox2.Gtk.Box+BoxChild
            this.label4 = new Gtk.Label();
            this.label4.Name = "label4";
            this.label4.LabelProp = Mono.Unix.Catalog.GetString("<b>Would you like a new game?</b>");
            this.label4.UseMarkup = true;
            this.vbox2.Add(this.label4);
            Gtk.Box.BoxChild w9 = ((Gtk.Box.BoxChild)(this.vbox2[this.label4]));
            w9.Position = 2;
            w9.Expand = false;
            w9.Fill = false;
            w9.Padding = ((uint)(8));
            w1.Add(this.vbox2);
            Gtk.Box.BoxChild w10 = ((Gtk.Box.BoxChild)(w1[this.vbox2]));
            w10.Position = 0;
            w10.Expand = false;
            w10.Fill = false;
            // Container child dialog1_VBox.Gtk.Box+BoxChild
            this.hseparator1 = new Gtk.HSeparator();
            this.hseparator1.Name = "hseparator1";
            w1.Add(this.hseparator1);
            Gtk.Box.BoxChild w11 = ((Gtk.Box.BoxChild)(w1[this.hseparator1]));
            w11.PackType = ((Gtk.PackType)(1));
            w11.Position = 2;
            w11.Expand = false;
            w11.Fill = false;
            // Internal child YahtzeeSharp.dlgFinished.ActionArea
            Gtk.HButtonBox w12 = this.ActionArea;
            w12.Name = "dialog1_ActionArea";
            w12.Spacing = 10;
            w12.BorderWidth = ((uint)(5));
            w12.LayoutStyle = ((Gtk.ButtonBoxStyle)(1));
            // Container child dialog1_ActionArea.Gtk.ButtonBox+ButtonBoxChild
            this.cmdNo = new Gtk.Button();
            this.cmdNo.CanDefault = true;
            this.cmdNo.CanFocus = true;
            this.cmdNo.Name = "cmdNo";
            this.cmdNo.UseStock = true;
            this.cmdNo.UseUnderline = true;
            this.cmdNo.Label = "gtk-no";
            this.AddActionWidget(this.cmdNo, -9);
            Gtk.ButtonBox.ButtonBoxChild w13 = ((Gtk.ButtonBox.ButtonBoxChild)(w12[this.cmdNo]));
            w13.Expand = false;
            w13.Fill = false;
            // Container child dialog1_ActionArea.Gtk.ButtonBox+ButtonBoxChild
            this.cmdYes = new Gtk.Button();
            this.cmdYes.CanDefault = true;
            this.cmdYes.CanFocus = true;
            this.cmdYes.Name = "cmdYes";
            this.cmdYes.UseStock = true;
            this.cmdYes.UseUnderline = true;
            this.cmdYes.Label = "gtk-yes";
            this.AddActionWidget(this.cmdYes, -8);
            Gtk.ButtonBox.ButtonBoxChild w14 = ((Gtk.ButtonBox.ButtonBoxChild)(w12[this.cmdYes]));
            w14.Position = 1;
            w14.Expand = false;
            w14.Fill = false;
            if ((this.Child != null)) {
                this.Child.ShowAll();
            }
            this.DefaultWidth = 411;
            this.DefaultHeight = 289;
            this.Show();
            this.cmdNo.Clicked += new System.EventHandler(this.OnCmdNoClicked);
            this.cmdYes.Clicked += new System.EventHandler(this.OnCmdYesClicked);
        }
    }
}
