// ------------------------------------------------------------------------------
//  <autogenerated>
//      This code was generated by a tool.
//      Mono Runtime Version: 2.0.50727.42
// 
//      Changes to this file may cause incorrect behavior and will be lost if 
//      the code is regenerated.
//  </autogenerated>
// ------------------------------------------------------------------------------

namespace YahtzeeSharp {
    
    
    public partial class frmError {
        
        private Gtk.VBox vbox2;
        
        private Gtk.Frame frame2;
        
        private Gtk.Label label3;
        
        private Gtk.Frame frame3;
        
        private Gtk.Expander expander1;
        
        private Gtk.ScrolledWindow scrolledwindow2;
        
        private Gtk.TextView txtErrorDetails;
        
        private Gtk.Label GtkLabel3;
        
        private Gtk.Alignment alignment1;
        
        private Gtk.HSeparator hseparator3;
        
        private Gtk.Label label1;
        
        private Gtk.Button btnNo;
        
        private Gtk.Button btnYes;
        
        protected virtual void Build() {
            Stetic.Gui.Initialize(this);
            // Widget YahtzeeSharp.frmError
            this.Events = ((Gdk.EventMask)(256));
            this.Name = "YahtzeeSharp.frmError";
            this.Title = Mono.Unix.Catalog.GetString("An error has occured.");
            this.WindowPosition = ((Gtk.WindowPosition)(4));
            this.Modal = true;
            this.AllowShrink = true;
            this.HasSeparator = false;
            // Internal child YahtzeeSharp.frmError.VBox
            Gtk.VBox w1 = this.VBox;
            w1.Events = ((Gdk.EventMask)(256));
            w1.Name = "dialog_VBox";
            w1.BorderWidth = ((uint)(2));
            // Container child dialog_VBox.Gtk.Box+BoxChild
            this.vbox2 = new Gtk.VBox();
            this.vbox2.Name = "vbox2";
            // Container child vbox2.Gtk.Box+BoxChild
            this.frame2 = new Gtk.Frame();
            this.frame2.Name = "frame2";
            // Container child frame2.Gtk.Container+ContainerChild
            this.label3 = new Gtk.Label();
            this.label3.Name = "label3";
            this.label3.LabelProp = "An error has occured. I appologyze for the inconvinience.\nI would appriciate it if you would take a minute to send the \nerror to me so I can make the program better. ";
            this.frame2.Add(this.label3);
            this.vbox2.Add(this.frame2);
            Gtk.Box.BoxChild w3 = ((Gtk.Box.BoxChild)(this.vbox2[this.frame2]));
            w3.Position = 0;
            w3.Expand = false;
            w3.Fill = false;
            w3.Padding = ((uint)(4));
            // Container child vbox2.Gtk.Box+BoxChild
            this.frame3 = new Gtk.Frame();
            this.frame3.Name = "frame3";
            // Container child frame3.Gtk.Container+ContainerChild
            this.expander1 = new Gtk.Expander(null);
            this.expander1.CanFocus = true;
            this.expander1.Name = "expander1";
            // Container child expander1.Gtk.Container+ContainerChild
            this.scrolledwindow2 = new Gtk.ScrolledWindow();
            this.scrolledwindow2.CanFocus = true;
            this.scrolledwindow2.Name = "scrolledwindow2";
            // Container child scrolledwindow2.Gtk.Container+ContainerChild
            this.txtErrorDetails = new Gtk.TextView();
            this.txtErrorDetails.HeightRequest = 124;
            this.txtErrorDetails.CanFocus = true;
            this.txtErrorDetails.Events = ((Gdk.EventMask)(2097152));
            this.txtErrorDetails.Name = "txtErrorDetails";
            this.txtErrorDetails.Editable = false;
            this.txtErrorDetails.WrapMode = ((Gtk.WrapMode)(2));
            this.txtErrorDetails.PixelsAboveLines = 4;
            this.txtErrorDetails.RightMargin = 5;
            this.scrolledwindow2.Add(this.txtErrorDetails);
            this.expander1.Add(this.scrolledwindow2);
            this.GtkLabel3 = new Gtk.Label();
            this.GtkLabel3.Name = "GtkLabel3";
            this.GtkLabel3.LabelProp = Mono.Unix.Catalog.GetString("<b>Error Details</b>");
            this.GtkLabel3.UseMarkup = true;
            this.GtkLabel3.UseUnderline = true;
            this.expander1.LabelWidget = this.GtkLabel3;
            this.frame3.Add(this.expander1);
            this.vbox2.Add(this.frame3);
            Gtk.Box.BoxChild w7 = ((Gtk.Box.BoxChild)(this.vbox2[this.frame3]));
            w7.Position = 1;
            // Container child vbox2.Gtk.Box+BoxChild
            this.alignment1 = new Gtk.Alignment(0.5F, 0.5F, 1F, 1F);
            this.alignment1.Name = "alignment1";
            this.alignment1.TopPadding = ((uint)(8));
            this.alignment1.BottomPadding = ((uint)(8));
            // Container child alignment1.Gtk.Container+ContainerChild
            this.hseparator3 = new Gtk.HSeparator();
            this.hseparator3.Name = "hseparator3";
            this.alignment1.Add(this.hseparator3);
            this.vbox2.Add(this.alignment1);
            Gtk.Box.BoxChild w9 = ((Gtk.Box.BoxChild)(this.vbox2[this.alignment1]));
            w9.Position = 2;
            w9.Expand = false;
            w9.Fill = false;
            w1.Add(this.vbox2);
            Gtk.Box.BoxChild w10 = ((Gtk.Box.BoxChild)(w1[this.vbox2]));
            w10.Position = 0;
            // Container child dialog_VBox.Gtk.Box+BoxChild
            this.label1 = new Gtk.Label();
            this.label1.Name = "label1";
            this.label1.LabelProp = Mono.Unix.Catalog.GetString("<b>Do you want to report this error over email?</b>");
            this.label1.UseMarkup = true;
            w1.Add(this.label1);
            Gtk.Box.BoxChild w11 = ((Gtk.Box.BoxChild)(w1[this.label1]));
            w11.Position = 1;
            w11.Expand = false;
            w11.Fill = false;
            w11.Padding = ((uint)(5));
            // Internal child YahtzeeSharp.frmError.ActionArea
            Gtk.HButtonBox w12 = this.ActionArea;
            w12.Events = ((Gdk.EventMask)(256));
            w12.Name = "YahtzeeSharp.frmError_ActionArea";
            w12.Spacing = 6;
            w12.BorderWidth = ((uint)(5));
            w12.LayoutStyle = ((Gtk.ButtonBoxStyle)(1));
            // Container child YahtzeeSharp.frmError_ActionArea.Gtk.ButtonBox+ButtonBoxChild
            this.btnNo = new Gtk.Button();
            this.btnNo.CanFocus = true;
            this.btnNo.Name = "btnNo";
            this.btnNo.UseStock = true;
            this.btnNo.UseUnderline = true;
            this.btnNo.Label = "gtk-no";
            this.AddActionWidget(this.btnNo, -9);
            Gtk.ButtonBox.ButtonBoxChild w13 = ((Gtk.ButtonBox.ButtonBoxChild)(w12[this.btnNo]));
            w13.Expand = false;
            w13.Fill = false;
            // Container child YahtzeeSharp.frmError_ActionArea.Gtk.ButtonBox+ButtonBoxChild
            this.btnYes = new Gtk.Button();
            this.btnYes.CanDefault = true;
            this.btnYes.CanFocus = true;
            this.btnYes.Name = "btnYes";
            this.btnYes.UseStock = true;
            this.btnYes.UseUnderline = true;
            this.btnYes.Label = "gtk-yes";
            this.AddActionWidget(this.btnYes, -8);
            Gtk.ButtonBox.ButtonBoxChild w14 = ((Gtk.ButtonBox.ButtonBoxChild)(w12[this.btnYes]));
            w14.Position = 1;
            w14.Expand = false;
            w14.Fill = false;
            if ((this.Child != null)) {
                this.Child.ShowAll();
            }
            this.DefaultWidth = 545;
            this.DefaultHeight = 214;
            this.Show();
            this.btnNo.Clicked += new System.EventHandler(this.OnBtnNoClicked);
            this.btnYes.Entered += new System.EventHandler(this.OnBtnYesEntered);
        }
    }
}
