// ------------------------------------------------------------------------------
//  <autogenerated>
//      This code was generated by a tool.
//      Mono Runtime Version: 2.0.50727.42
// 
//      Changes to this file may cause incorrect behavior and will be lost if 
//      the code is regenerated.
//  </autogenerated>
// ------------------------------------------------------------------------------

namespace YahtzeeSharp {
    
    
    public partial class frmLicense {
        
        private Gtk.Frame frame1;
        
        private Gtk.Alignment GtkAlignment;
        
        private Gtk.ScrolledWindow GtkScrolledWindow;
        
        private Gtk.TextView txtText;
        
        private Gtk.Button buttonCancel;
        
        protected virtual void Build() {
            Stetic.Gui.Initialize(this);
            // Widget YahtzeeSharp.frmLicense
            this.WidthRequest = 700;
            this.HeightRequest = 500;
            this.Name = "YahtzeeSharp.frmLicense";
            this.Title = Mono.Unix.Catalog.GetString("GNU GENERAL PUBLIC LICENSE Version 3");
            this.WindowPosition = ((Gtk.WindowPosition)(4));
            this.Modal = true;
            this.BorderWidth = ((uint)(2));
            this.AllowShrink = true;
            this.DefaultWidth = 700;
            this.DefaultHeight = 500;
            this.DestroyWithParent = true;
            this.SkipPagerHint = true;
            this.SkipTaskbarHint = true;
            this.HasSeparator = false;
            // Internal child YahtzeeSharp.frmLicense.VBox
            Gtk.VBox w1 = this.VBox;
            w1.Name = "dialog1_VBox";
            w1.BorderWidth = ((uint)(2));
            // Container child dialog1_VBox.Gtk.Box+BoxChild
            this.frame1 = new Gtk.Frame();
            this.frame1.Name = "frame1";
            this.frame1.ShadowType = ((Gtk.ShadowType)(1));
            // Container child frame1.Gtk.Container+ContainerChild
            this.GtkAlignment = new Gtk.Alignment(0.5F, 0.5F, 1F, 1F);
            this.GtkAlignment.Name = "GtkAlignment";
            this.GtkAlignment.LeftPadding = ((uint)(5));
            this.GtkAlignment.TopPadding = ((uint)(5));
            this.GtkAlignment.RightPadding = ((uint)(5));
            this.GtkAlignment.BottomPadding = ((uint)(5));
            // Container child GtkAlignment.Gtk.Container+ContainerChild
            this.GtkScrolledWindow = new Gtk.ScrolledWindow();
            this.GtkScrolledWindow.Name = "GtkScrolledWindow";
            this.GtkScrolledWindow.ShadowType = ((Gtk.ShadowType)(1));
            // Container child GtkScrolledWindow.Gtk.Container+ContainerChild
            this.txtText = new Gtk.TextView();
            this.txtText.CanFocus = true;
            this.txtText.Name = "txtText";
            this.txtText.Editable = false;
            this.txtText.CursorVisible = false;
            this.txtText.AcceptsTab = false;
            this.txtText.WrapMode = ((Gtk.WrapMode)(2));
            this.txtText.PixelsAboveLines = 2;
            this.txtText.PixelsBelowLines = 2;
            this.txtText.PixelsInsideWrap = 2;
            this.txtText.LeftMargin = 8;
            this.txtText.RightMargin = 8;
            this.GtkScrolledWindow.Add(this.txtText);
            this.GtkAlignment.Add(this.GtkScrolledWindow);
            this.frame1.Add(this.GtkAlignment);
            w1.Add(this.frame1);
            Gtk.Box.BoxChild w5 = ((Gtk.Box.BoxChild)(w1[this.frame1]));
            w5.Position = 0;
            // Internal child YahtzeeSharp.frmLicense.ActionArea
            Gtk.HButtonBox w6 = this.ActionArea;
            w6.Name = "dialog1_ActionArea";
            w6.Spacing = 6;
            w6.BorderWidth = ((uint)(5));
            w6.LayoutStyle = ((Gtk.ButtonBoxStyle)(1));
            // Container child dialog1_ActionArea.Gtk.ButtonBox+ButtonBoxChild
            this.buttonCancel = new Gtk.Button();
            this.buttonCancel.CanDefault = true;
            this.buttonCancel.CanFocus = true;
            this.buttonCancel.Name = "buttonCancel";
            this.buttonCancel.UseStock = true;
            this.buttonCancel.UseUnderline = true;
            this.buttonCancel.Label = "gtk-close";
            this.AddActionWidget(this.buttonCancel, -7);
            Gtk.ButtonBox.ButtonBoxChild w7 = ((Gtk.ButtonBox.ButtonBoxChild)(w6[this.buttonCancel]));
            w7.Expand = false;
            w7.Fill = false;
            if ((this.Child != null)) {
                this.Child.ShowAll();
            }
            this.Show();
            this.buttonCancel.Clicked += new System.EventHandler(this.OnButtonCancelClicked);
        }
    }
}
