// ------------------------------------------------------------------------------
//  <autogenerated>
//      This code was generated by a tool.
//      Mono Runtime Version: 2.0.50727.42
// 
//      Changes to this file may cause incorrect behavior and will be lost if 
//      the code is regenerated.
//  </autogenerated>
// ------------------------------------------------------------------------------

namespace YahtzeeSharp {
    
    
    public partial class frmAbout {
        
        private Gtk.HBox hbox2;
        
        private Gtk.VBox vbox4;
        
        private Gtk.Alignment alignment3;
        
        private Gtk.Image image3;
        
        private Gtk.VBox vbox5;
        
        private Gtk.Alignment alignment2;
        
        private Gtk.Label lblName;
        
        private Gtk.Alignment alignment4;
        
        private Gtk.HSeparator hseparator4;
        
        private Gtk.HBox hbox6;
        
        private Gtk.Table table1;
        
        private Gtk.Alignment algAuthor;
        
        private Gtk.Alignment algLicense;
        
        private Gtk.Alignment algProjectPage;
        
        private Gtk.Alignment algWebSite;
        
        private Gtk.Alignment alignment11;
        
        private Gtk.Label lblVersion4;
        
        private Gtk.Alignment alignment12;
        
        private Gtk.Label lblVersion2;
        
        private Gtk.Alignment alignment5;
        
        private Gtk.Label label5;
        
        private Gtk.Alignment alignment7;
        
        private Gtk.Label label4;
        
        private Gtk.Alignment alignment8;
        
        private Gtk.Label lblVersion;
        
        private Gtk.Alignment alignment9;
        
        private Gtk.Label label6;
        
        private Gtk.HSeparator hseparator3;
        
        private Gtk.Frame frame1;
        
        private Gtk.ScrolledWindow GtkScrolledWindow;
        
        private Gtk.TextView textview1;
        
        private Gtk.Alignment alignment1;
        
        private Gtk.HBox hbox1;
        
        private Gtk.Button cmdBitRock;
        
        private Gtk.Image image1;
        
        private Gtk.Button cmdSharpDevelop;
        
        private Gtk.Image image4;
        
        private Gtk.Button cmdMono;
        
        private Gtk.Image image5;
        
        private Gtk.HSeparator hseparator2;
        
        private Gtk.Button btnOk;
        
        protected virtual void Build() {
            Stetic.Gui.Initialize(this);
            // Widget YahtzeeSharp.frmAbout
            this.WidthRequest = 700;
            this.HeightRequest = 600;
            this.Events = ((Gdk.EventMask)(256));
            this.Name = "YahtzeeSharp.frmAbout";
            this.Title = Mono.Unix.Catalog.GetString("About Yahtzee Sharp");
            this.Icon = Gdk.Pixbuf.LoadFromResource("YSlogo.png");
            this.TypeHint = ((Gdk.WindowTypeHint)(1));
            this.WindowPosition = ((Gtk.WindowPosition)(2));
            this.BorderWidth = ((uint)(2));
            this.AllowShrink = true;
            this.DefaultWidth = 700;
            this.DefaultHeight = 600;
            this.DestroyWithParent = true;
            this.SkipPagerHint = true;
            this.SkipTaskbarHint = true;
            this.HasSeparator = false;
            // Internal child YahtzeeSharp.frmAbout.VBox
            Gtk.VBox w1 = this.VBox;
            w1.Events = ((Gdk.EventMask)(256));
            w1.Name = "dialog_VBox";
            w1.BorderWidth = ((uint)(2));
            // Container child dialog_VBox.Gtk.Box+BoxChild
            this.hbox2 = new Gtk.HBox();
            this.hbox2.Name = "hbox2";
            // Container child hbox2.Gtk.Box+BoxChild
            this.vbox4 = new Gtk.VBox();
            this.vbox4.Name = "vbox4";
            // Container child vbox4.Gtk.Box+BoxChild
            this.alignment3 = new Gtk.Alignment(0.5F, 1F, 1F, 0.1F);
            this.alignment3.Name = "alignment3";
            this.alignment3.LeftPadding = ((uint)(11));
            this.alignment3.TopPadding = ((uint)(40));
            // Container child alignment3.Gtk.Container+ContainerChild
            this.image3 = new Gtk.Image();
            this.image3.Name = "image3";
            this.image3.Pixbuf = Gdk.Pixbuf.LoadFromResource("YahtzeeSharp.png");
            this.alignment3.Add(this.image3);
            this.vbox4.Add(this.alignment3);
            Gtk.Box.BoxChild w3 = ((Gtk.Box.BoxChild)(this.vbox4[this.alignment3]));
            w3.Position = 0;
            w3.Expand = false;
            w3.Fill = false;
            w3.Padding = ((uint)(13));
            this.hbox2.Add(this.vbox4);
            Gtk.Box.BoxChild w4 = ((Gtk.Box.BoxChild)(this.hbox2[this.vbox4]));
            w4.Position = 0;
            w4.Expand = false;
            w4.Fill = false;
            // Container child hbox2.Gtk.Box+BoxChild
            this.vbox5 = new Gtk.VBox();
            this.vbox5.Name = "vbox5";
            this.vbox5.BorderWidth = ((uint)(9));
            // Container child vbox5.Gtk.Box+BoxChild
            this.alignment2 = new Gtk.Alignment(0.46F, 0.5F, 0.04F, 1F);
            this.alignment2.Name = "alignment2";
            this.alignment2.BottomPadding = ((uint)(8));
            // Container child alignment2.Gtk.Container+ContainerChild
            this.lblName = new Gtk.Label();
            this.lblName.Name = "lblName";
            this.lblName.Xalign = 0.58F;
            this.lblName.Yalign = 0.53F;
            this.lblName.LabelProp = Mono.Unix.Catalog.GetString("<span font_size=\"xx-large\"><b>YahtzeeSharp</b></span>");
            this.lblName.UseMarkup = true;
            this.alignment2.Add(this.lblName);
            this.vbox5.Add(this.alignment2);
            Gtk.Box.BoxChild w6 = ((Gtk.Box.BoxChild)(this.vbox5[this.alignment2]));
            w6.Position = 0;
            w6.Expand = false;
            w6.Fill = false;
            // Container child vbox5.Gtk.Box+BoxChild
            this.alignment4 = new Gtk.Alignment(0.5F, 0.5F, 1F, 1F);
            this.alignment4.Name = "alignment4";
            this.alignment4.BottomPadding = ((uint)(10));
            // Container child alignment4.Gtk.Container+ContainerChild
            this.hseparator4 = new Gtk.HSeparator();
            this.hseparator4.Name = "hseparator4";
            this.alignment4.Add(this.hseparator4);
            this.vbox5.Add(this.alignment4);
            Gtk.Box.BoxChild w8 = ((Gtk.Box.BoxChild)(this.vbox5[this.alignment4]));
            w8.Position = 1;
            w8.Expand = false;
            w8.Fill = false;
            // Container child vbox5.Gtk.Box+BoxChild
            this.hbox6 = new Gtk.HBox();
            this.hbox6.Name = "hbox6";
            this.hbox6.Spacing = 6;
            // Container child hbox6.Gtk.Box+BoxChild
            this.table1 = new Gtk.Table(((uint)(5)), ((uint)(2)), false);
            this.table1.Name = "table1";
            this.table1.RowSpacing = ((uint)(6));
            this.table1.ColumnSpacing = ((uint)(6));
            // Container child table1.Gtk.Table+TableChild
            this.algAuthor = new Gtk.Alignment(0.01F, 0.5F, 0.01F, 1F);
            this.algAuthor.Name = "algAuthor";
            this.algAuthor.LeftPadding = ((uint)(2));
            this.table1.Add(this.algAuthor);
            Gtk.Table.TableChild w9 = ((Gtk.Table.TableChild)(this.table1[this.algAuthor]));
            w9.LeftAttach = ((uint)(1));
            w9.RightAttach = ((uint)(2));
            w9.XOptions = ((Gtk.AttachOptions)(4));
            w9.YOptions = ((Gtk.AttachOptions)(4));
            // Container child table1.Gtk.Table+TableChild
            this.algLicense = new Gtk.Alignment(0.01F, 0.5F, 0.01F, 1F);
            this.algLicense.Name = "algLicense";
            this.algLicense.LeftPadding = ((uint)(2));
            this.table1.Add(this.algLicense);
            Gtk.Table.TableChild w10 = ((Gtk.Table.TableChild)(this.table1[this.algLicense]));
            w10.TopAttach = ((uint)(2));
            w10.BottomAttach = ((uint)(3));
            w10.LeftAttach = ((uint)(1));
            w10.RightAttach = ((uint)(2));
            w10.XOptions = ((Gtk.AttachOptions)(4));
            w10.YOptions = ((Gtk.AttachOptions)(4));
            // Container child table1.Gtk.Table+TableChild
            this.algProjectPage = new Gtk.Alignment(0.01F, 0.5F, 0.01F, 1F);
            this.algProjectPage.Name = "algProjectPage";
            this.algProjectPage.LeftPadding = ((uint)(2));
            this.table1.Add(this.algProjectPage);
            Gtk.Table.TableChild w11 = ((Gtk.Table.TableChild)(this.table1[this.algProjectPage]));
            w11.TopAttach = ((uint)(3));
            w11.BottomAttach = ((uint)(4));
            w11.LeftAttach = ((uint)(1));
            w11.RightAttach = ((uint)(2));
            w11.XOptions = ((Gtk.AttachOptions)(4));
            w11.YOptions = ((Gtk.AttachOptions)(4));
            // Container child table1.Gtk.Table+TableChild
            this.algWebSite = new Gtk.Alignment(0.01F, 0.5F, 0.01F, 1F);
            this.algWebSite.Name = "algWebSite";
            this.algWebSite.LeftPadding = ((uint)(2));
            this.table1.Add(this.algWebSite);
            Gtk.Table.TableChild w12 = ((Gtk.Table.TableChild)(this.table1[this.algWebSite]));
            w12.TopAttach = ((uint)(4));
            w12.BottomAttach = ((uint)(5));
            w12.LeftAttach = ((uint)(1));
            w12.RightAttach = ((uint)(2));
            w12.XOptions = ((Gtk.AttachOptions)(4));
            w12.YOptions = ((Gtk.AttachOptions)(4));
            // Container child table1.Gtk.Table+TableChild
            this.alignment11 = new Gtk.Alignment(1F, 0.5F, 0.01F, 1F);
            this.alignment11.Name = "alignment11";
            this.alignment11.RightPadding = ((uint)(2));
            // Container child alignment11.Gtk.Container+ContainerChild
            this.lblVersion4 = new Gtk.Label();
            this.lblVersion4.Name = "lblVersion4";
            this.lblVersion4.LabelProp = Mono.Unix.Catalog.GetString("Project Page:");
            this.alignment11.Add(this.lblVersion4);
            this.table1.Add(this.alignment11);
            Gtk.Table.TableChild w14 = ((Gtk.Table.TableChild)(this.table1[this.alignment11]));
            w14.TopAttach = ((uint)(3));
            w14.BottomAttach = ((uint)(4));
            w14.XOptions = ((Gtk.AttachOptions)(4));
            w14.YOptions = ((Gtk.AttachOptions)(4));
            // Container child table1.Gtk.Table+TableChild
            this.alignment12 = new Gtk.Alignment(1F, 0.5F, 0.01F, 1F);
            this.alignment12.Name = "alignment12";
            this.alignment12.RightPadding = ((uint)(2));
            // Container child alignment12.Gtk.Container+ContainerChild
            this.lblVersion2 = new Gtk.Label();
            this.lblVersion2.Name = "lblVersion2";
            this.lblVersion2.LabelProp = Mono.Unix.Catalog.GetString("License:");
            this.alignment12.Add(this.lblVersion2);
            this.table1.Add(this.alignment12);
            Gtk.Table.TableChild w16 = ((Gtk.Table.TableChild)(this.table1[this.alignment12]));
            w16.TopAttach = ((uint)(2));
            w16.BottomAttach = ((uint)(3));
            w16.XOptions = ((Gtk.AttachOptions)(4));
            w16.YOptions = ((Gtk.AttachOptions)(4));
            // Container child table1.Gtk.Table+TableChild
            this.alignment5 = new Gtk.Alignment(1F, 0.5F, 0.01F, 1F);
            this.alignment5.Name = "alignment5";
            this.alignment5.RightPadding = ((uint)(2));
            // Container child alignment5.Gtk.Container+ContainerChild
            this.label5 = new Gtk.Label();
            this.label5.Name = "label5";
            this.label5.LabelProp = Mono.Unix.Catalog.GetString("Version:");
            this.alignment5.Add(this.label5);
            this.table1.Add(this.alignment5);
            Gtk.Table.TableChild w18 = ((Gtk.Table.TableChild)(this.table1[this.alignment5]));
            w18.TopAttach = ((uint)(1));
            w18.BottomAttach = ((uint)(2));
            w18.XOptions = ((Gtk.AttachOptions)(4));
            w18.YOptions = ((Gtk.AttachOptions)(4));
            // Container child table1.Gtk.Table+TableChild
            this.alignment7 = new Gtk.Alignment(1F, 0.01F, 0.01F, 1F);
            this.alignment7.Name = "alignment7";
            this.alignment7.RightPadding = ((uint)(2));
            // Container child alignment7.Gtk.Container+ContainerChild
            this.label4 = new Gtk.Label();
            this.label4.Name = "label4";
            this.label4.LabelProp = Mono.Unix.Catalog.GetString("Author:");
            this.alignment7.Add(this.label4);
            this.table1.Add(this.alignment7);
            Gtk.Table.TableChild w20 = ((Gtk.Table.TableChild)(this.table1[this.alignment7]));
            w20.XOptions = ((Gtk.AttachOptions)(4));
            w20.YOptions = ((Gtk.AttachOptions)(4));
            // Container child table1.Gtk.Table+TableChild
            this.alignment8 = new Gtk.Alignment(0.01F, 0.5F, 0.01F, 1F);
            this.alignment8.Name = "alignment8";
            this.alignment8.LeftPadding = ((uint)(2));
            // Container child alignment8.Gtk.Container+ContainerChild
            this.lblVersion = new Gtk.Label();
            this.lblVersion.Name = "lblVersion";
            this.lblVersion.LabelProp = Mono.Unix.Catalog.GetString("lblVersion");
            this.alignment8.Add(this.lblVersion);
            this.table1.Add(this.alignment8);
            Gtk.Table.TableChild w22 = ((Gtk.Table.TableChild)(this.table1[this.alignment8]));
            w22.TopAttach = ((uint)(1));
            w22.BottomAttach = ((uint)(2));
            w22.LeftAttach = ((uint)(1));
            w22.RightAttach = ((uint)(2));
            w22.XOptions = ((Gtk.AttachOptions)(4));
            w22.YOptions = ((Gtk.AttachOptions)(4));
            // Container child table1.Gtk.Table+TableChild
            this.alignment9 = new Gtk.Alignment(1F, 0.5F, 0.01F, 1F);
            this.alignment9.Name = "alignment9";
            this.alignment9.RightPadding = ((uint)(2));
            // Container child alignment9.Gtk.Container+ContainerChild
            this.label6 = new Gtk.Label();
            this.label6.Name = "label6";
            this.label6.LabelProp = Mono.Unix.Catalog.GetString("Web Site:");
            this.alignment9.Add(this.label6);
            this.table1.Add(this.alignment9);
            Gtk.Table.TableChild w24 = ((Gtk.Table.TableChild)(this.table1[this.alignment9]));
            w24.TopAttach = ((uint)(4));
            w24.BottomAttach = ((uint)(5));
            w24.XOptions = ((Gtk.AttachOptions)(4));
            w24.YOptions = ((Gtk.AttachOptions)(4));
            this.hbox6.Add(this.table1);
            Gtk.Box.BoxChild w25 = ((Gtk.Box.BoxChild)(this.hbox6[this.table1]));
            w25.Position = 0;
            w25.Expand = false;
            w25.Fill = false;
            this.vbox5.Add(this.hbox6);
            Gtk.Box.BoxChild w26 = ((Gtk.Box.BoxChild)(this.vbox5[this.hbox6]));
            w26.Position = 2;
            w26.Expand = false;
            w26.Fill = false;
            // Container child vbox5.Gtk.Box+BoxChild
            this.hseparator3 = new Gtk.HSeparator();
            this.hseparator3.WidthRequest = 250;
            this.hseparator3.HeightRequest = 10;
            this.hseparator3.Name = "hseparator3";
            this.vbox5.Add(this.hseparator3);
            Gtk.Box.BoxChild w27 = ((Gtk.Box.BoxChild)(this.vbox5[this.hseparator3]));
            w27.Position = 3;
            w27.Expand = false;
            w27.Fill = false;
            // Container child vbox5.Gtk.Box+BoxChild
            this.frame1 = new Gtk.Frame();
            this.frame1.Name = "frame1";
            this.frame1.ShadowType = ((Gtk.ShadowType)(1));
            this.frame1.BorderWidth = ((uint)(2));
            // Container child frame1.Gtk.Container+ContainerChild
            this.GtkScrolledWindow = new Gtk.ScrolledWindow();
            this.GtkScrolledWindow.Name = "GtkScrolledWindow";
            this.GtkScrolledWindow.ShadowType = ((Gtk.ShadowType)(1));
            // Container child GtkScrolledWindow.Gtk.Container+ContainerChild
            this.textview1 = new Gtk.TextView();
            this.textview1.HeightRequest = 201;
            this.textview1.CanFocus = true;
            this.textview1.Name = "textview1";
            this.textview1.Editable = false;
            this.textview1.AcceptsTab = false;
            this.textview1.WrapMode = ((Gtk.WrapMode)(2));
            this.textview1.PixelsAboveLines = 3;
            this.textview1.LeftMargin = 4;
            this.textview1.RightMargin = 4;
            this.GtkScrolledWindow.Add(this.textview1);
            this.frame1.Add(this.GtkScrolledWindow);
            this.vbox5.Add(this.frame1);
            Gtk.Box.BoxChild w30 = ((Gtk.Box.BoxChild)(this.vbox5[this.frame1]));
            w30.Position = 4;
            this.hbox2.Add(this.vbox5);
            Gtk.Box.BoxChild w31 = ((Gtk.Box.BoxChild)(this.hbox2[this.vbox5]));
            w31.Position = 1;
            w1.Add(this.hbox2);
            Gtk.Box.BoxChild w32 = ((Gtk.Box.BoxChild)(w1[this.hbox2]));
            w32.Position = 0;
            w32.Expand = false;
            w32.Fill = false;
            // Container child dialog_VBox.Gtk.Box+BoxChild
            this.alignment1 = new Gtk.Alignment(0.5F, 0.5F, 0.5F, 0.5F);
            this.alignment1.Name = "alignment1";
            // Container child alignment1.Gtk.Container+ContainerChild
            this.hbox1 = new Gtk.HBox();
            this.hbox1.Name = "hbox1";
            this.hbox1.Spacing = 35;
            this.hbox1.BorderWidth = ((uint)(4));
            // Container child hbox1.Gtk.Box+BoxChild
            this.cmdBitRock = new Gtk.Button();
            this.cmdBitRock.CanFocus = true;
            this.cmdBitRock.Name = "cmdBitRock";
            this.cmdBitRock.Relief = ((Gtk.ReliefStyle)(2));
            // Container child cmdBitRock.Gtk.Container+ContainerChild
            this.image1 = new Gtk.Image();
            this.image1.Name = "image1";
            this.image1.Pixbuf = Gdk.Pixbuf.LoadFromResource("installersby_tiny.png");
            this.cmdBitRock.Add(this.image1);
            this.cmdBitRock.Label = null;
            this.hbox1.Add(this.cmdBitRock);
            Gtk.Box.BoxChild w34 = ((Gtk.Box.BoxChild)(this.hbox1[this.cmdBitRock]));
            w34.Position = 0;
            w34.Expand = false;
            w34.Fill = false;
            // Container child hbox1.Gtk.Box+BoxChild
            this.cmdSharpDevelop = new Gtk.Button();
            this.cmdSharpDevelop.CanFocus = true;
            this.cmdSharpDevelop.Name = "cmdSharpDevelop";
            this.cmdSharpDevelop.Relief = ((Gtk.ReliefStyle)(2));
            // Container child cmdSharpDevelop.Gtk.Container+ContainerChild
            this.image4 = new Gtk.Image();
            this.image4.Name = "image4";
            this.image4.Pixbuf = Gdk.Pixbuf.LoadFromResource("SharpDevelop.png");
            this.cmdSharpDevelop.Add(this.image4);
            this.cmdSharpDevelop.Label = null;
            this.hbox1.Add(this.cmdSharpDevelop);
            Gtk.Box.BoxChild w36 = ((Gtk.Box.BoxChild)(this.hbox1[this.cmdSharpDevelop]));
            w36.Position = 1;
            w36.Expand = false;
            w36.Fill = false;
            // Container child hbox1.Gtk.Box+BoxChild
            this.cmdMono = new Gtk.Button();
            this.cmdMono.CanFocus = true;
            this.cmdMono.Name = "cmdMono";
            this.cmdMono.Relief = ((Gtk.ReliefStyle)(2));
            // Container child cmdMono.Gtk.Container+ContainerChild
            this.image5 = new Gtk.Image();
            this.image5.Name = "image5";
            this.image5.Pixbuf = Gdk.Pixbuf.LoadFromResource("mono-gorilla.png");
            this.cmdMono.Add(this.image5);
            this.cmdMono.Label = null;
            this.hbox1.Add(this.cmdMono);
            Gtk.Box.BoxChild w38 = ((Gtk.Box.BoxChild)(this.hbox1[this.cmdMono]));
            w38.Position = 2;
            w38.Expand = false;
            w38.Fill = false;
            this.alignment1.Add(this.hbox1);
            w1.Add(this.alignment1);
            Gtk.Box.BoxChild w40 = ((Gtk.Box.BoxChild)(w1[this.alignment1]));
            w40.Position = 1;
            w40.Expand = false;
            w40.Fill = false;
            // Container child dialog_VBox.Gtk.Box+BoxChild
            this.hseparator2 = new Gtk.HSeparator();
            this.hseparator2.Name = "hseparator2";
            w1.Add(this.hseparator2);
            Gtk.Box.BoxChild w41 = ((Gtk.Box.BoxChild)(w1[this.hseparator2]));
            w41.PackType = ((Gtk.PackType)(1));
            w41.Position = 3;
            w41.Expand = false;
            w41.Fill = false;
            // Internal child YahtzeeSharp.frmAbout.ActionArea
            Gtk.HButtonBox w42 = this.ActionArea;
            w42.Events = ((Gdk.EventMask)(256));
            w42.Name = "YahtzeeSharp.frmAbout_ActionArea";
            w42.Spacing = 6;
            w42.BorderWidth = ((uint)(5));
            w42.LayoutStyle = ((Gtk.ButtonBoxStyle)(1));
            // Container child YahtzeeSharp.frmAbout_ActionArea.Gtk.ButtonBox+ButtonBoxChild
            this.btnOk = new Gtk.Button();
            this.btnOk.HeightRequest = 31;
            this.btnOk.CanDefault = true;
            this.btnOk.CanFocus = true;
            this.btnOk.Name = "btnOk";
            this.btnOk.Label = Mono.Unix.Catalog.GetString(" Ok ");
            this.AddActionWidget(this.btnOk, 0);
            Gtk.ButtonBox.ButtonBoxChild w43 = ((Gtk.ButtonBox.ButtonBoxChild)(w42[this.btnOk]));
            w43.Expand = false;
            w43.Fill = false;
            if ((this.Child != null)) {
                this.Child.ShowAll();
            }
            this.Show();
            this.cmdBitRock.Clicked += new System.EventHandler(this.OnCmdBitRockClicked);
            this.cmdBitRock.Entered += new System.EventHandler(this.OnCmdEntered);
            this.cmdBitRock.Left += new System.EventHandler(this.OnCmdLeft);
            this.cmdSharpDevelop.Clicked += new System.EventHandler(this.OnCmdSharpDevelopClicked);
            this.cmdSharpDevelop.Entered += new System.EventHandler(this.OnCmdEntered);
            this.cmdSharpDevelop.Left += new System.EventHandler(this.OnCmdLeft);
            this.cmdMono.Clicked += new System.EventHandler(this.OnCmdMonoClicked);
            this.cmdMono.Entered += new System.EventHandler(this.OnCmdEntered);
            this.cmdMono.Left += new System.EventHandler(this.OnCmdLeft);
            this.btnOk.Clicked += new System.EventHandler(this.OnBtnOkClicked);
        }
    }
}
